package jp.co.spiritek.smapushsample2;

import android.app.Application;
import android.content.Intent;
import android.graphics.Color;

import jp.smapush.SPKNotification;
import jp.smapush.SPKNotificationDialogConfig;
import jp.smapush.SPKNotificationHandler;
import jp.smapush.SPKNotificationManager;

/**
 * SMA PUSHサンプル2
 * <p>
 *     リッチ通知の表示タイミングおよび配色を変更します。
 * </p>
 */
public class MyApplication extends Application {

    /**
     * リッチ通知を保留中の通知オブジェクト
     */
    private SPKNotification mPendingNotification;

    @Override
    public void onCreate() {
        super.onCreate();

        // アプリID/共有パスワードを設定します
        SPKNotificationManager.initialize(this, "00000000-0000-0000-0000-000000000000", "XXXXXXXXXXXXXXXX", BuildConfig.DEBUG);

        // GCMのプロジェクト番号をSender IDとして設定します
        SPKNotificationManager.getInstance().setSenderId("000000000000");

        // 詳細ログ出力を有効化します
        SPKNotificationManager.getInstance().enableVerboseLog(BuildConfig.DEBUG);

        // 通知ハンドラをオーバーライドします
        SPKNotificationManager.getInstance().setNotificationHandler(new SPKNotificationHandler() {
            @Override
            protected void onRequestSecondDialog(SPKNotification notification) {
                // 通知オブジェクトを退避する(この時点ではリッチ通知画面を表示しない)
                mPendingNotification = notification;

                // MainActivityから showPendingSecondDialog を呼ばせる
                Intent intent = new Intent(getContext(), MainActivity.class);
                intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP | Intent.FLAG_ACTIVITY_NEW_TASK);
                startActivity(intent);
            }
        });
    }

    public boolean showPendingSecondDialog() {
        if (mPendingNotification == null)
            return false;

        // 退避しておいた通知オブジェクトのリッチ通知画面を表示する
        SPKNotificationDialogConfig config = new SPKNotificationDialogConfig();
        config.titleTextColor = Color.WHITE;
        config.titleBackgroundColor = Color.GRAY;
        config.buttonTextColor = Color.WHITE;
        config.buttonBackgroundColor = Color.RED;
        mPendingNotification.showSecondDialog(this, config);

        mPendingNotification = null;
        return true;
    }

}
